@@ -1,20 +1,25 @@
 #include "nextclient.h"
-#include <qdatetime.h>
-#include <qdrawutil.h>
-#include <qlayout.h>
-#include <qpainter.h>
-#include <qbitmap.h>
-#include <qlabel.h>
-#include <qtooltip.h>
+
+#include <QStyle>
+#include <QPainter>
+//#include <qdatetime.h>
+//#include <qdrawutil.h>
+//#include <qlayout.h>
+//#include <qpainter.h>
+//#include <qbitmap.h>
+//#include <qlabel.h>
+//#include <qtooltip.h>
+
 //Added by qt3to4:
-#include <QPaintEvent>
-#include <QEvent>
-#include <QHBoxLayout>
 #include <QBoxLayout>
-#include <QShowEvent>
+#include <QHBoxLayout>
 #include <QVBoxLayout>
+#include <QEvent>
+#include <QPaintEvent>
+#include <QShowEvent>
 #include <QResizeEvent>
 #include <QMouseEvent>
+
 #include <kdebug.h>
 #include <klocale.h>
 #include <kpixmapeffect.h>
@@ -164,16 +169,16 @@ static const unsigned char resize_bits[] = {
 //    0xfe, 0x01, 0xff, 0x03, 0xff, 0x03, 0xff, 0x03 };
 
 
-static KPixmap *aTitlePix;
-static KPixmap *iTitlePix;
-static KPixmap *aFramePix;
-static KPixmap *iFramePix;
-static KPixmap *aHandlePix;
-static KPixmap *iHandlePix;
-static KPixmap *aBtn;
-static KPixmap *aBtnDown;
-static KPixmap *iBtn;
-static KPixmap *iBtnDown;
+static QPixmap *aTitlePix;
+static QPixmap *iTitlePix;
+static QPixmap *aFramePix;
+static QPixmap *iFramePix;
+static QPixmap *aHandlePix;
+static QPixmap *iHandlePix;
+static QPixmap *aBtn;
+static QPixmap *aBtnDown;
+static QPixmap *iBtn;
+static QPixmap *iBtnDown;
 static QColor *btnForeground;
 static bool pixmaps_created = false;
 
@@ -205,58 +210,51 @@ static void create_pixmaps(NextClientFactory *f)
     titleHeight &= ~1; // Make title height even
     if (titleHeight < 16) titleHeight = 16;
 
-    aTitlePix = new KPixmap();
-    aTitlePix->resize(32, titleHeight - 2);
+    aTitlePix = new QPixmap(32, titleHeight - 2);
     KPixmapEffect::gradient(*aTitlePix,
                             options()->color(KDecoration::ColorTitleBar, true),
                             options()->color(KDecoration::ColorTitleBlend, true),
                             KPixmapEffect::VerticalGradient);
-    iTitlePix = new KPixmap();
-    iTitlePix->resize(32, titleHeight - 2);
+    iTitlePix = new QPixmap(32, titleHeight - 2);
     KPixmapEffect::gradient(*iTitlePix,
                             options()->color(KDecoration::ColorTitleBar, false),
                             options()->color(KDecoration::ColorTitleBlend, false),
                             KPixmapEffect::VerticalGradient);
     // Bottom frame gradient
-    aFramePix = new KPixmap();
-    aFramePix->resize(32, handleSize);
+    aFramePix = new QPixmap(32, handleSize);
     KPixmapEffect::gradient(*aFramePix,
                             options()->color(KDecoration::ColorFrame, true).light(150),
                             options()->color(KDecoration::ColorFrame, true).dark(120),
                             KPixmapEffect::VerticalGradient);
-    iFramePix = new KPixmap();
-    iFramePix->resize(32, handleSize);
+    iFramePix = new QPixmap(32, handleSize);
     KPixmapEffect::gradient(*iFramePix,
                             options()->color(KDecoration::ColorFrame, false).light(150),
                             options()->color(KDecoration::ColorFrame, false).dark(120),
                             KPixmapEffect::VerticalGradient);
 
     // Handle gradient
-    aHandlePix = new KPixmap();
-    aHandlePix->resize(32, handleSize);
+    aHandlePix = new QPixmap(32, handleSize);
     KPixmapEffect::gradient(*aHandlePix,
                             options()->color(KDecoration::ColorHandle, true).light(150),
                             options()->color(KDecoration::ColorHandle, true).dark(120),
                             KPixmapEffect::VerticalGradient);
-    iHandlePix = new KPixmap();
-    iHandlePix->resize(32, handleSize);
+    iHandlePix = new QPixmap(32, handleSize);
     KPixmapEffect::gradient(*iHandlePix,
                             options()->color(KDecoration::ColorHandle, false).light(150),
                             options()->color(KDecoration::ColorHandle, false).dark(120),
                             KPixmapEffect::VerticalGradient);
 
     int btnWidth = titleHeight;
-    iBtn = new KPixmap;
-    iBtn->resize(btnWidth, btnWidth);
-    iBtnDown = new KPixmap;
-    iBtnDown->resize(btnWidth, btnWidth);
-    aBtn = new KPixmap;
-    aBtn->resize(btnWidth, btnWidth);
-    aBtnDown = new KPixmap;
-    aBtnDown->resize(btnWidth, btnWidth);
-    KPixmap internal;
+    iBtn = new QPixmap(btnWidth, btnWidth);
+    iBtnDown = new QPixmap(btnWidth, btnWidth);
+    aBtn = new QPixmap(btnWidth, btnWidth);
+    aBtnDown = new QPixmap(btnWidth, btnWidth);
     int internalHeight = btnWidth - 6;
-    internal.resize(internalHeight, internalHeight);
+    QPixmap internal(internalHeight, internalHeight);
+    QRect dest(internal.rect());
+    dest.moveTo(3, 3);
+
+    QPainter p;
 
     // inactive buttons
     QColor c(options()->color(KDecoration::ColorButtonBg, false));
@@ -264,13 +262,21 @@ static void create_pixmaps(NextClientFactory *f)
                             KPixmapEffect::DiagonalGradient);
     KPixmapEffect::gradient(internal, c.dark(120), c.light(120),
                             KPixmapEffect::DiagonalGradient);
-    bitBlt(iBtn, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
+    p.begin(iBtn);
+    p.drawPixmap(dest, internal, internal.rect());
+    p.end();
+    //bitBlt(iBtn, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
+
 
     KPixmapEffect::gradient(*iBtnDown, c.dark(120), c.light(120),
                             KPixmapEffect::DiagonalGradient);
     KPixmapEffect::gradient(internal, c.light(120), c.dark(120),
                             KPixmapEffect::DiagonalGradient);
-    bitBlt(iBtnDown, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
+    //bitBlt(iBtnDown, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
+    p.begin(iBtnDown);
+    dest.moveTo(3, 3);
+    p.drawPixmap(dest, internal, internal.rect());
+    p.end();
 
     // active buttons
     c = options()->color(KDecoration::ColorButtonBg, true);
@@ -278,15 +284,20 @@ static void create_pixmaps(NextClientFactory *f)
                             KPixmapEffect::DiagonalGradient);
     KPixmapEffect::gradient(internal, c.dark(120), c.light(120),
                             KPixmapEffect::DiagonalGradient);
-    bitBlt(aBtn, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
+    //bitBlt(aBtn, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
+    p.begin(aBtn);
+    p.drawPixmap(dest, internal, internal.rect());
+    p.end();
 
     KPixmapEffect::gradient(*aBtnDown, c.dark(120), c.light(120),
                             KPixmapEffect::DiagonalGradient);
     KPixmapEffect::gradient(internal, c.light(120), c.dark(120),
                             KPixmapEffect::DiagonalGradient);
-    bitBlt(aBtnDown, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
+    //bitBlt(aBtnDown, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
+    p.begin(aBtnDown);
+    p.drawPixmap(dest, internal, internal.rect());
+    p.end();
 
-    QPainter p;
     p.begin(aBtn);
     p.setPen(Qt::black);
     p.drawRect(0, 0, btnWidth, btnWidth);
@@ -329,15 +340,15 @@ static void delete_pixmaps()
 
 // =====================================
 
-NextButton::NextButton(NextClient *parent, const char *name,
+NextButton::NextButton(NextClient *parent, 
                        const unsigned char *bitmap, int bw, int bh,
                        const QString& tip, const int realizeBtns)
-    : Q3Button(parent->widget(), name),
-      deco(NULL), client(parent), last_button(Qt::NoButton)
+    : QAbstractButton(parent->widget()),
+      client(parent), last_button(Qt::NoButton)
 {
     realizeButtons = realizeBtns;
 
-    setBackgroundMode( Qt::NoBackground );
+    setAttribute(Qt::WA_NoSystemBackground);
     resize(titleHeight, titleHeight);
     setFixedSize(titleHeight, titleHeight);
 
@@ -349,52 +360,59 @@ NextButton::NextButton(NextClient *parent, const char *name,
 
 void NextButton::reset()
 {
-    repaint(false);
+    repaint();
 }
 
 void NextButton::setBitmap(const unsigned char *bitmap, int w, int h)
 {
-    deco = new QBitmap(w, h, bitmap, true);
-    deco->setMask(*deco);
+    QSize s(w, h);
+    deco = QBitmap::fromData(s, bitmap, QImage::Format_MonoLSB);
+    deco.setMask(deco);
     repaint();
 }
 
-void NextButton::drawButton(QPainter *p)
+void NextButton::paintEvent(QPaintEvent *)
 {
-    if(client->isActive())
-        p->drawPixmap(0, 0, isDown() ? *aBtnDown : *aBtn);
+    QPainter p(this);
+    if (client->isActive())
+        p.drawPixmap(0, 0, isDown() ? *aBtnDown : *aBtn);
     else
-        p->drawPixmap(0, 0, isDown() ? *iBtnDown : *iBtn);
+        p.drawPixmap(0, 0, isDown() ? *iBtnDown : *iBtn);
 
     // If we have a decoration, draw it; otherwise, we have the menu
     // button (remember, we set the bitmap to NULL).
     int offset;
-    if (deco) {
+    if (!deco.isNull()) {
         offset = (titleHeight - 10) / 2 + (isDown() ? 1 : 0);
-        p->setPen(*btnForeground);
-        p->drawPixmap(offset, offset, *deco);
+        p.setPen(*btnForeground);
+        p.drawPixmap(offset, offset, deco);
     } else {
         offset = (titleHeight - 16) / 2;
-	KPixmap btnpix = client->icon().pixmap(QIcon::Small,
+	QPixmap btnpix = client->icon().pixmap(
+		style()->pixelMetric(QStyle::PM_SmallIconSize),
 		client->isActive() ? QIcon::Normal : QIcon::Disabled);
-        p->drawPixmap( offset, offset, btnpix );
+        p.drawPixmap(offset, offset, btnpix);
     }
 }
 
 void NextButton::mousePressEvent( QMouseEvent* e )
 {
     last_button = e->button();
-    QMouseEvent me( e->type(), e->pos(), e->globalPos(),
-                    (e->button()&realizeButtons)?Qt::LeftButton:Qt::NoButton, e->state() );
-    Q3Button::mousePressEvent( &me );
+    QMouseEvent me(e->type(), e->pos(), e->globalPos(),
+	    (e->button() & realizeButtons) ? Qt::LeftButton : Qt::NoButton,
+	    (e->button() & realizeButtons) ? Qt::LeftButton : Qt::NoButton,
+	    e->modifiers());
+    QAbstractButton::mousePressEvent(&me);
 }
 
 void NextButton::mouseReleaseEvent( QMouseEvent* e )
 {
     last_button = e->button();
-    QMouseEvent me( e->type(), e->pos(), e->globalPos(),
-                    (e->button()&realizeButtons)?Qt::LeftButton:Qt::NoButton, e->state() );
-    Q3Button::mouseReleaseEvent( &me );
+    QMouseEvent me(e->type(), e->pos(), e->globalPos(),
+	    (e->button() & realizeButtons) ? Qt::LeftButton : Qt::NoButton,
+	    (e->button() & realizeButtons) ? Qt::LeftButton : Qt::NoButton,
+	    e->modifiers());
+    QAbstractButton::mouseReleaseEvent(&me);
 }
 
 // =====================================
@@ -406,13 +424,17 @@ NextClient::NextClient(KDecorationBridge *b, KDecorationFactory *f)
 
 void NextClient::init()
 {
-    createMainWidget(WResizeNoErase | WStaticContents);
+    createMainWidget();
+    widget()->setAttribute(Qt::WA_NoSystemBackground);
     widget()->installEventFilter(this);
 
-    widget()->setBackgroundMode( NoBackground );
+    //widget()->setBackgroundMode( NoBackground );
 
     QVBoxLayout *mainLayout = new QVBoxLayout(widget());
-    QBoxLayout  *titleLayout = new QBoxLayout(0, QBoxLayout::LeftToRight, 0, 0, 0);
+    mainLayout->setMargin(0);
+    QBoxLayout  *titleLayout = new QBoxLayout(QBoxLayout::LeftToRight);
+    titleLayout->setMargin(0);
+    titleLayout->setSpacing(0);
     QHBoxLayout *windowLayout = new QHBoxLayout();
     mainLayout->addLayout(titleLayout);
     mainLayout->addLayout(windowLayout, 1);
@@ -482,11 +504,11 @@ void NextClient::initializeButtonsAndTitlebar(QBoxLayout* titleLayout)
 void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 {
     for (unsigned int i=0; i<spec.length(); i++) {
-        switch (spec[i].latin1()) {
+        switch (spec[i].toLatin1()) {
         case 'A':
             if (isMaximizable()) {
                 button[MAXIMIZE_IDX] =
-                    new NextButton(this, "maximize", maximize_bits, 10, 10,
+                    new NextButton(this, maximize_bits, 10, 10,
                                    i18n("Maximize"), Qt::LeftButton|Qt::MidButton|Qt::RightButton);
                 titleLayout->addWidget( button[MAXIMIZE_IDX] );
                 connect( button[MAXIMIZE_IDX], SIGNAL(clicked()),
@@ -496,8 +518,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 
         case 'H':
 	    if (providesContextHelp()) {
-		button[HELP_IDX] = new NextButton(this,
-			"help", question_bits, 10, 10, i18n("Help"));
+		button[HELP_IDX] = new NextButton(this, question_bits, 10, 10, i18n("Help"));
 		titleLayout->addWidget( button[HELP_IDX] );
 		connect( button[HELP_IDX], SIGNAL(clicked()),
 			 this, SLOT(showContextHelp()) );
@@ -507,7 +528,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
         case 'I':
             if (isMinimizable()) {
                 button[ICONIFY_IDX] =
-                    new NextButton(this, "iconify", iconify_bits, 10, 10,
+                    new NextButton(this, iconify_bits, 10, 10,
                                    i18n("Minimize"));
                 titleLayout->addWidget( button[ICONIFY_IDX] );
                 connect( button[ICONIFY_IDX], SIGNAL(clicked()),
@@ -517,7 +538,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 
         case 'M':
             button[MENU_IDX] =
-                new NextButton(this, "menu", NULL, 10, 10, i18n("Menu"), Qt::LeftButton|Qt::RightButton);
+                new NextButton(this, NULL, 10, 10, i18n("Menu"), Qt::LeftButton|Qt::RightButton);
             titleLayout->addWidget( button[MENU_IDX] );
             // NOTE DIFFERENCE: capture pressed(), not clicked()
             connect( button[MENU_IDX], SIGNAL(pressed()),
@@ -526,7 +547,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 
         case 'L':
             button[SHADE_IDX] =
-                new NextButton(this, "shade", NULL, 0, 0, i18n("Shade"));
+                new NextButton(this, NULL, 0, 0, i18n("Shade"));
             titleLayout->addWidget( button[SHADE_IDX] );
             connect( button[SHADE_IDX], SIGNAL(clicked()),
                      this, SLOT(shadeClicked()) );
@@ -536,7 +557,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 
         case 'S':
             button[STICKY_IDX] =
-                new NextButton(this, "sticky", NULL, 0, 0, i18n("On all desktops"));
+                new NextButton(this, NULL, 0, 0, i18n("On all desktops"));
             titleLayout->addWidget( button[STICKY_IDX] );
             connect( button[STICKY_IDX], SIGNAL(clicked()),
                      this, SLOT(toggleOnAllDesktops()) );
@@ -545,7 +566,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
             break;
 
 	case 'F':
-            button[ABOVE_IDX] = new NextButton(this, "above", NULL, 0, 0, "");
+            button[ABOVE_IDX] = new NextButton(this, NULL, 0, 0, "");
             titleLayout->addWidget( button[ABOVE_IDX] );
             connect( button[ABOVE_IDX], SIGNAL(clicked()),
                      this, SLOT(aboveClicked()) );
@@ -555,7 +576,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 	    break;
 
 	case 'B':
-            button[BELOW_IDX] = new NextButton(this, "below", NULL, 0, 0, "");
+            button[BELOW_IDX] = new NextButton(this, NULL, 0, 0, "");
             titleLayout->addWidget( button[BELOW_IDX] );
             connect( button[BELOW_IDX], SIGNAL(clicked()),
                      this, SLOT(belowClicked()) );
@@ -567,7 +588,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 	case 'X':
             if (isCloseable()) {
 		button[CLOSE_IDX] =
-		    new NextButton(this, "close", close_bits, 10, 10,
+		    new NextButton(this, close_bits, 10, 10,
 				   i18n("Close"));
 		titleLayout->addWidget(button[CLOSE_IDX]);
 		connect(button[CLOSE_IDX], SIGNAL(clicked()),
@@ -578,7 +599,7 @@ void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 	case 'R':
             if (mustDrawHandle()) {
 		button[RESIZE_IDX] =
-		    new NextButton(this, "resize", resize_bits, 10, 10,
+		    new NextButton(this, resize_bits, 10, 10,
 				   i18n("Resize"));
 		titleLayout->addWidget(button[RESIZE_IDX]);
 		// NOTE DIFFERENCE: capture pressed(), not clicked()
@@ -611,7 +632,7 @@ bool NextClient::mustDrawHandle() const
 void NextClient::iconChange()
 {
     if (button[MENU_IDX] && button[MENU_IDX]->isVisible())
-	button[MENU_IDX]->repaint(false);
+	button[MENU_IDX]->repaint();
 }
 
 void NextClient::menuButtonPressed()
@@ -681,7 +702,7 @@ void NextClient::resizeEvent(QResizeEvent *)
 
 void NextClient::captionChange()
 {
-    widget()->repaint(titlebar->geometry(), false);
+    widget()->repaint(titlebar->geometry());
 }
 
 
@@ -700,7 +721,7 @@ void NextClient::paintEvent( QPaintEvent* )
     p.drawTiledPixmap(t.x()+1, t.y()+1, t.width()-2, t.height()-2,
                       isActive() ? *aTitlePix : *iTitlePix);
     qDrawShadePanel(&p, t.x(), t.y(), t.width(), t.height()-1,
-                   options()->colorGroup(KDecoration::ColorTitleBar, isActive()));
+                   options()->palette(KDecoration::ColorTitleBar, isActive()));
     p.drawLine(t.x(), t.bottom(), t.right(), t.bottom());
 
 #if 0
@@ -725,7 +746,7 @@ void NextClient::paintEvent( QPaintEvent* )
         int corner = 16 + 3*handleSize/2;
 	qDrawShadePanel(&p,
 		fr.x() + 1, fr.bottom() - handleSize, corner-1, handleSize,
-		options()->colorGroup(KDecoration::ColorHandle, isActive()),
+		options()->palette(KDecoration::ColorHandle, isActive()),
 		false);
 	p.drawTiledPixmap(fr.x() + 2, fr.bottom() - handleSize + 1,
 		corner - 3, handleSize - 2, isActive() ? *aHandlePix : *iHandlePix);
@@ -733,7 +754,7 @@ void NextClient::paintEvent( QPaintEvent* )
 	qDrawShadePanel(&p,
 		fr.x() + corner, fr.bottom() - handleSize,
 		fr.width() - 2*corner, handleSize,
-		options()->colorGroup(KDecoration::ColorFrame, isActive()),
+		options()->palette(KDecoration::ColorFrame, isActive()),
 		false);
 	p.drawTiledPixmap(fr.x() + corner + 1, fr.bottom() - handleSize + 1,
 		fr.width() - 2*corner - 2, handleSize - 2,
@@ -741,7 +762,7 @@ void NextClient::paintEvent( QPaintEvent* )
 
 	qDrawShadePanel(&p,
 		fr.right() - corner + 1, fr.bottom() - handleSize, corner - 1, handleSize,
-		options()->colorGroup(KDecoration::ColorHandle, isActive()),
+		options()->palette(KDecoration::ColorHandle, isActive()),
 		false);
 	p.drawTiledPixmap(fr.right() - corner + 2, fr.bottom() - handleSize + 1,
 		corner - 3, handleSize - 2, isActive() ? *aHandlePix : *iHandlePix);
@@ -764,7 +785,7 @@ void NextClient::desktopChange()
     bool on = isOnAllDesktops();
     if (NextButton * b = button[STICKY_IDX]) {
         b->setBitmap( on ? unsticky_bits : sticky_bits, 10, 10);
-	QToolTip::remove(b);
+	//QToolTip::remove(b);
 	b->setToolTip( on ? i18n("Not on all desktops") : i18n("On all desktops"));
     }
 }
@@ -774,7 +795,7 @@ void NextClient::maximizeChange()
     if (button[MAXIMIZE_IDX]) {
 	bool m = maximizeMode() == MaximizeFull;
 	//button[MAXIMIZE_IDX]->setBitmap(m ? minmax_bits : maximize_bits);
-	QToolTip::remove(button[MAXIMIZE_IDX]);
+	//QToolTip::remove(button[MAXIMIZE_IDX]);
 	button[MAXIMIZE_IDX]->setToolTip(
 		m ? i18n("Restore") : i18n("Maximize"));
     }
@@ -785,7 +806,7 @@ void NextClient::maximizeChange()
 
 void NextClient::activeChange()
 {
-    widget()->repaint(false);
+    widget()->repaint();
     slotReset();
 }
 
@@ -830,7 +851,7 @@ void NextClient::shadeChange()
 {
     if (NextButton *b = button[SHADE_IDX]) {
         b->setBitmap(isSetShade() ? unshade_bits : shade_bits, 10, 10);
-	QToolTip::remove(b);
+	//QToolTip::remove(b);
 	b->setToolTip( isSetShade() ? i18n("Unshade") : i18n("Shade"));
     }
 }
@@ -839,10 +860,10 @@ void NextClient::keepAboveChange(bool above)
 {
     if (NextButton *b = button[ABOVE_IDX]) {
         b->setBitmap(above ? from_above_bits : keep_above_bits, 10, 10);
-	QToolTip::remove(b);
+	//QToolTip::remove(b);
 	b->setToolTip( above ?
 		i18n("Do not keep above others") : i18n("Keep above others"));
-	b->repaint(false);
+	b->repaint();
     }
 }
 
@@ -850,10 +871,10 @@ void NextClient::keepBelowChange(bool below)
 {
     if (NextButton *b = button[BELOW_IDX]) {
         b->setBitmap(below ? from_below_bits : keep_below_bits, 10, 10);
-	QToolTip::remove(b);
+	//QToolTip::remove(b);
 	b->setToolTip( below ?
 		i18n("Do not keep below others") : i18n("Keep below others"));
-	b->repaint(false);
+	b->repaint();
     }
 }
 
@@ -906,7 +927,7 @@ bool NextClient::drawbound(const QRect& geom, bool /* clear */)
 {
     QPainter p(workspaceWidget());
     p.setPen(QPen(Qt::white, 3));
-    p.setRasterOp(Qt::XorROP);
+    p.setCompositionMode(QPainter::CompositionMode_Xor);
     p.drawRect(geom);
     int leftMargin = geom.left() + 2;
     p.fillRect(leftMargin, geom.top() + titleHeight - 1,
